Learn R Programming

mixpack (version 0.3.6)

get_hierarchical_partition: Build a hierchical partition from posterior probabilities

Description

This function applies the methodology described in [citar article] to build a hierarchy of classes using the weights or probabilities that an element belongs to each class

Usage

get_hierarchical_partition(post, omega, lambda, f_omega = NULL, f_lambda = NULL)

Arguments

post
dataframe of probabilities/weights (tau must be strictly positive)
omega
String giving the function name used to build the hierarchy. Available functions are: entr, prop, dich
lambda
String giving the function name used to build the hierarchy. Available functions are: entr, demp, demp.mod, coda, coda.norm, prop
f_omega
function with two parameters (v_tau, a). Parameter v_tau is a vector of probabilities, parameter a is the a selected class. omega(v_tau, a) gives the representativeness of element with probabities v_tau to class a
f_lambda
function with three parameters (v_tau, a, b). Parameter v_tau is a vector of probabilities, parameters a and b are classes to be combined.