Rdocumentation
powered by
Learn R Programming
mixpack (version 0.3.6)
clr_mixnorm: CLR evaluated on gaussian mixture model posterioris of X
Description
CLR evaluated on gaussian mixture model posterioris of X
Usage
clr_mixnorm(X, Pi, Mu, Sigma)
Arguments
X
dataframe where density function is evaluated
Pi
a vector indicating the mixing proportions
Mu
a two dimensional array where second component indicates the mean of each gaussian component
Sigma
a three dimensional array where third component indicates the variance of each gaussian component